[nautilus-actions] Refactor NAIContextual as NAIContext



commit 1c2fa0d8c97047b9a47cd8a512184eba4e67b938
Author: Pierre Wieser <pwieser trychlos org>
Date:   Thu Apr 1 21:20:14 2010 +0200

    Refactor NAIContextual as NAIContext

 ChangeLog                                          |   15 +++
 po/POTFILES.in                                     |    2 +-
 po/cs.po                                           |   48 +++++-----
 po/de.po                                           |   48 +++++-----
 po/es.po                                           |   72 ++++++++++----
 po/eu.po                                           |   48 +++++-----
 po/sl.po                                           |   52 +++++-----
 src/api/Makefile.am                                |    2 +-
 src/api/{na-icontextual.h => na-icontext.h}        |   46 ++++----
 src/api/na-object-api.h                            |    8 +-
 src/core/Makefile.am                               |    4 +-
 ...icontextual-factory.c => na-icontext-factory.c} |    0
 src/core/{na-icontextual.c => na-icontext.c}       |  108 ++++++++++----------
 src/core/na-object-action.c                        |    2 +-
 src/core/na-object-profile.c                       |    8 +-
 src/plugin-menu/nautilus-actions.c                 |    6 +-
 src/utils/nautilus-actions-run.c                   |    2 +-
 17 files changed, 261 insertions(+), 210 deletions(-)
---
diff --git a/ChangeLog b/ChangeLog
index 8aa737b..13abc0f 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -115,6 +115,21 @@
 
 2009-04-01 Pierre Wieser <pwieser trychlos org>
 
+	* src/api/na-icontextual.h: Renamed as src/api/na-icontext.h.
+	* src/core/na-icontextual.c: Renamed as src/core/na-icontext.c.
+	* src/core/na-icontextual-factory.c: Renamed as	src/core/na-icontext-factory.c.
+
+	* po/POTFILES.in:
+	* src/api/Makefile.am:
+	* src/api/na-icontext.h:
+	* src/api/na-object-api.h:
+	* src/core/Makefile.am:
+	* src/core/na-icontext.c:
+	* src/core/na-object-action.c:
+	* src/core/na-object-profile.c:
+	* src/plugin-menu/nautilus-actions.c:
+	* src/utils/nautilus-actions-run.c: Updated accordingly.
+
 	* src/api/na-object-api.h (na_object_prepare_for_paste):
 	* src/core/na-object-id.c (na_object_id_prepare_for_paste):
 	Parent is not always an action, may be a menu.
diff --git a/po/POTFILES.in b/po/POTFILES.in
index a270a17..799805d 100644
--- a/po/POTFILES.in
+++ b/po/POTFILES.in
@@ -1,7 +1,7 @@
 data/nautilus-actions-prefs.schemas.in
 src/core/na-exporter.c
 src/core/na-iabout.c
-src/core/na-icontextual-factory.c
+src/core/na-icontext-factory.c
 src/core/na-importer-ask.c
 src/core/na-importer-ask.ui
 src/core/na-io-provider.c
diff --git a/po/cs.po b/po/cs.po
index ad5a2f6..27888df 100644
--- a/po/cs.po
+++ b/po/cs.po
@@ -503,12 +503,12 @@ msgstr ""
 "Copyright %s 2005-2007 Frederic Ruaudel <grumz grumz net>\n"
 "Copyright %s 2009, 2010 Pierre Wieser <pwieser trychlos org>"
 
-#: ../src/core/na-icontextual-factory.c:47
+#: ../src/core/na-icontext-factory.c:47
 msgid "List of patterns to be matched against the selected file(s)/folder(s)"
 msgstr ""
 "Seznam vzorů, kterým má odpovídat vybraný soubor/složka Ä?i soubory/složky"
 
-#: ../src/core/na-icontextual-factory.c:48
+#: ../src/core/na-icontext-factory.c:48
 msgid ""
 "A list of strings with joker '*' or '?' to be matched against the name(s) of "
 "the selected file(s)/folder(s). Each selected items must match at least one "
@@ -524,7 +524,7 @@ msgstr ""
 "Toto nastavení se použije jen když je nÄ?co vybráno.\n"
 "Výchozí je â??*â??."
 
-#: ../src/core/na-icontextual-factory.c:65
+#: ../src/core/na-icontext-factory.c:65
 msgid ""
 "A pattern to be matched against basenames of selected file(s)/folder(s). May "
 "include wildcards (* or ?). You must set one option for each pattern you need"
@@ -533,16 +533,16 @@ msgstr ""
 "obsahovat divoké znaky (* nebo ?). Pro každý vzor, který potÅ?ebujete, musíte "
 "zadat tento pÅ?epínaÄ? zvlášť"
 
-#: ../src/core/na-icontextual-factory.c:68
-#: ../src/core/na-icontextual-factory.c:119
+#: ../src/core/na-icontext-factory.c:68
+#: ../src/core/na-icontext-factory.c:119
 msgid "<EXPR>"
 msgstr "<VÃ?RAZ>"
 
-#: ../src/core/na-icontextual-factory.c:74
+#: ../src/core/na-icontext-factory.c:74
 msgid "Whether the specified basenames are case sensitive (default)"
 msgstr "Zda se má u základních názvů rozlišovat velikost písmen (výchozí)"
 
-#: ../src/core/na-icontextual-factory.c:75
+#: ../src/core/na-icontext-factory.c:75
 msgid ""
 "Must be set to 'true' if the filename patterns are case sensitive, to "
 "'false' otherwise. E.g., if you need to match a filename in a case-sensitive "
@@ -557,7 +557,7 @@ msgstr ""
 "Toto nastavení se použije jen když je nÄ?co vybráno.\n"
 "Výchozí je â??zapnutoâ??."
 
-#: ../src/core/na-icontextual-factory.c:99
+#: ../src/core/na-icontext-factory.c:99
 msgid ""
 "List of patterns to be matched against the mimetypes of the selected file(s)/"
 "folder(s)"
@@ -565,7 +565,7 @@ msgstr ""
 "Seznam vzorů, kterým má odpovídat typ MIME vybraného souboru/složky Ä?i "
 "souborů/složek"
 
-#: ../src/core/na-icontextual-factory.c:100
+#: ../src/core/na-icontext-factory.c:100
 msgid ""
 "A list of strings with joker '*' to be matched against the mimetypes of the "
 "selected file(s)/folder(s). Each selected items must match at least one of "
@@ -579,7 +579,7 @@ msgstr ""
 "Toto nastavení se použije jen když je nÄ?co vybráno.\n"
 "Výchozí je â??*â??."
 
-#: ../src/core/na-icontextual-factory.c:116
+#: ../src/core/na-icontext-factory.c:116
 msgid ""
 "A pattern to be matched against mimetypes of selected file(s)/folder(s). May "
 "include wildcards (* or ?). You must set one option for each pattern you need"
@@ -588,11 +588,11 @@ msgstr ""
 "souborů/složek. Může obsahovat divoké znaky (* nebo ?). Pro každý vzor, "
 "který potÅ?ebujete, musíte zadat tento pÅ?epínaÄ? zvlášť"
 
-#: ../src/core/na-icontextual-factory.c:125
+#: ../src/core/na-icontext-factory.c:125
 msgid "Whether the profile applies to files"
 msgstr "Zda se profil použije na soubory"
 
-#: ../src/core/na-icontextual-factory.c:126
+#: ../src/core/na-icontext-factory.c:126
 msgid ""
 "Set to 'true' if the selection can have files, to 'false' otherwise.\n"
 "This setting is tied in with the 'isdir' setting. The valid combinations "
@@ -619,11 +619,11 @@ msgstr ""
 "Toto nastavení se použije jen když je nÄ?co vybráno.\n"
 "Výchozí je â??zapnutoâ??."
 
-#: ../src/core/na-icontextual-factory.c:153
+#: ../src/core/na-icontext-factory.c:153
 msgid "Whether the profile applies to folders"
 msgstr "Zda se profil použije na složky"
 
-#: ../src/core/na-icontextual-factory.c:154
+#: ../src/core/na-icontext-factory.c:154
 msgid ""
 "Set to 'true' if the selection can have folders, to 'false' otherwise.\n"
 "This setting is tied in with the 'isfile' setting. The valid combinations "
@@ -650,11 +650,11 @@ msgstr ""
 "Toto nastavení se použije jen když je nÄ?co vybráno.\n"
 "Výchozí je â??vypnutoâ??."
 
-#: ../src/core/na-icontextual-factory.c:181
+#: ../src/core/na-icontext-factory.c:181
 msgid "Whether the selection may be multiple"
 msgstr "Zda může být výbÄ?r vícenásobný"
 
-#: ../src/core/na-icontextual-factory.c:182
+#: ../src/core/na-icontext-factory.c:182
 msgid ""
 "If you need more than one files or folders to be selected, set this key to "
 "'true'. If you want just one file or folder, set it to 'false'.\n"
@@ -667,7 +667,7 @@ msgstr ""
 "Toto nastavení se použije jen když je nÄ?co vybráno.\n"
 "Výchozí je â??vypnutoâ??."
 
-#: ../src/core/na-icontextual-factory.c:204
+#: ../src/core/na-icontext-factory.c:204
 msgid ""
 "List of schemes to be matched against those of selected file(s)/folder(s)"
 msgstr ""
@@ -675,7 +675,7 @@ msgstr ""
 "souborům/složkám"
 
 #. too long string for iso c: 510 (max=509)
-#: ../src/core/na-icontextual-factory.c:206
+#: ../src/core/na-icontext-factory.c:206
 msgid ""
 "Defines the list of valid schemes to be matched against the selected items. "
 "The scheme is the protocol used to access the files. The keyword to use is "
@@ -712,7 +712,7 @@ msgstr ""
 "speciální schéma â??x-nautilus-desktopâ??.\n"
 "Výchozí je â??fileâ??."
 
-#: ../src/core/na-icontextual-factory.c:233
+#: ../src/core/na-icontext-factory.c:233
 msgid ""
 "A valid GIO scheme where the selected file(s)/folder(s) should be located. "
 "You must set one option for each scheme you need"
@@ -720,7 +720,7 @@ msgstr ""
 "Platné schéma GIO, kde by mÄ?ly být umístÄ?ny vybrané soubory/složky. Pro "
 "každé schéma, které potÅ?ebujete, musíte zadat tento pÅ?epínaÄ? zvlášť"
 
-#: ../src/core/na-icontextual-factory.c:235
+#: ../src/core/na-icontext-factory.c:235
 #: ../src/core/na-object-action-factory.c:158
 #: ../src/core/na-object-item-factory.c:94
 #: ../src/core/na-object-item-factory.c:116
@@ -729,11 +729,11 @@ msgstr ""
 msgid "<STRING>"
 msgstr "<Å?ETÄ?ZEC>"
 
-#: ../src/core/na-icontextual-factory.c:241
+#: ../src/core/na-icontext-factory.c:241
 msgid "List of folders"
 msgstr "Seznam složek"
 
-#: ../src/core/na-icontextual-factory.c:242
+#: ../src/core/na-icontext-factory.c:242
 msgid ""
 "Defines the list of valid paths to be matched against the current folder.\n"
 " All folders 'under' the specified path are considered valid.\n"
@@ -743,7 +743,7 @@ msgstr ""
 "VÅ¡echny složky â??podâ?? zadanou cestou jsou považovány za platné.\n"
 "Výchozí je â??/â??."
 
-#: ../src/core/na-icontextual-factory.c:256
+#: ../src/core/na-icontext-factory.c:256
 msgid ""
 "The path of a (parent) directory for which the item will be displayed. You "
 "must set one option for each folder you need"
@@ -751,7 +751,7 @@ msgstr ""
 "Cesta k (rodiÄ?ovské) složce, pro kterou se položka zobrazí. Pro každou "
 "složku, kterou potÅ?ebujete, musíte zadat tento pÅ?epínaÄ? zvlášť"
 
-#: ../src/core/na-icontextual-factory.c:258
+#: ../src/core/na-icontext-factory.c:258
 #: ../src/core/na-object-profile-factory.c:86
 #: ../src/utils/nautilus-actions-new.c:132
 msgid "<PATH>"
diff --git a/po/de.po b/po/de.po
index 63b190b..65ce133 100644
--- a/po/de.po
+++ b/po/de.po
@@ -521,13 +521,13 @@ msgstr ""
 "Copyright %s 2005-2007 Frederic Ruaudel <grumz grumz net>\n"
 "Copyright %s 2009, 2010 Pierre Wieser <pwieser trychlos org>"
 
-#: ../src/core/na-icontextual-factory.c:47
+#: ../src/core/na-icontext-factory.c:47
 msgid "List of patterns to be matched against the selected file(s)/folder(s)"
 msgstr ""
 "Die Liste der Muster, die auf die ausgewählten Datei(en) und Ordner zutreffen "
 "müssen"
 
-#: ../src/core/na-icontextual-factory.c:48
+#: ../src/core/na-icontext-factory.c:48
 msgid ""
 "A list of strings with joker '*' or '?' to be matched against the name(s) of "
 "the selected file(s)/folder(s). Each selected items must match at least one "
@@ -540,7 +540,7 @@ msgstr ""
 "muss mindestens einem der Muster entsprechen, damit die Aktion erscheint.\n"
 "Vorgabe ist »*«."
 
-#: ../src/core/na-icontextual-factory.c:65
+#: ../src/core/na-icontext-factory.c:65
 msgid ""
 "A pattern to be matched against basenames of selected file(s)/folder(s). May "
 "include wildcards (* or ?). You must set one option for each pattern you need"
@@ -549,18 +549,18 @@ msgstr ""
 "Ordnern zutreffen muss (Sie müssen für jedes Muster, das Sie benötigen, ein "
 "weiteres erstellen)."
 
-#: ../src/core/na-icontextual-factory.c:68
-#: ../src/core/na-icontextual-factory.c:119
+#: ../src/core/na-icontext-factory.c:68
+#: ../src/core/na-icontext-factory.c:119
 msgid "<EXPR>"
 msgstr "<AUSDRUCK>"
 
-#: ../src/core/na-icontextual-factory.c:74
+#: ../src/core/na-icontext-factory.c:74
 msgid "Whether the specified basenames are case sensitive (default)"
 msgstr ""
 "Ist gesetzt, falls für die angegebenen Basisnamen Gro�-/Kleinschreibung "
 "berücksichtigt werden soll (Vorgabe)"
 
-#: ../src/core/na-icontextual-factory.c:75
+#: ../src/core/na-icontext-factory.c:75
 msgid ""
 "Must be set to 'true' if the filename patterns are case sensitive, to 'false' "
 "otherwise. E.g., if you need to match a filename in a case-sensitive manner, "
@@ -577,7 +577,7 @@ msgstr ""
 "Dies wirkt sich nur auf die Zielauswahl aus, sofern eine Auswahl existiert.\n"
 "Vorgabe ist »wahr«."
 
-#: ../src/core/na-icontextual-factory.c:99
+#: ../src/core/na-icontext-factory.c:99
 msgid ""
 "List of patterns to be matched against the mimetypes of the selected file(s)/"
 "folder(s)"
@@ -585,7 +585,7 @@ msgstr ""
 "Die Liste der Muster, die beim Filtern der ausgewählten Datei(en) oder Ordner "
 "nach dem MIME-Typen zutreffen müssen"
 
-#: ../src/core/na-icontextual-factory.c:100
+#: ../src/core/na-icontext-factory.c:100
 msgid ""
 "A list of strings with joker '*' to be matched against the mimetypes of the "
 "selected file(s)/folder(s). Each selected items must match at least one of "
@@ -599,7 +599,7 @@ msgstr ""
 "Dies wirkt sich nur auf die Zielauswahl aus, sofern eine Auswahl existiert.\n"
 "Vorgabe ist »*«."
 
-#: ../src/core/na-icontextual-factory.c:116
+#: ../src/core/na-icontext-factory.c:116
 msgid ""
 "A pattern to be matched against mimetypes of selected file(s)/folder(s). May "
 "include wildcards (* or ?). You must set one option for each pattern you need"
@@ -608,11 +608,11 @@ msgstr ""
 "oder Ordnern zutreffen muss (Sie müssen für jedes Muster, das Sie benötigen, "
 "ein weiteres erstellen)."
 
-#: ../src/core/na-icontextual-factory.c:125
+#: ../src/core/na-icontext-factory.c:125
 msgid "Whether the profile applies to files"
 msgstr "Legt fest, ob das Profil auf Dateien angewendet werden soll"
 
-#: ../src/core/na-icontextual-factory.c:126
+#: ../src/core/na-icontext-factory.c:126
 msgid ""
 "Set to 'true' if the selection can have files, to 'false' otherwise.\n"
 "This setting is tied in with the 'isdir' setting. The valid combinations "
@@ -641,11 +641,11 @@ msgstr ""
 "Dies trifft nur zu, wenn auf eine Auswahl abgezielt wird.\n"
 "Vorgabe ist »wahr«."
 
-#: ../src/core/na-icontextual-factory.c:153
+#: ../src/core/na-icontext-factory.c:153
 msgid "Whether the profile applies to folders"
 msgstr "Legt fest, ob das Profil auf Ordner angewendet werden soll"
 
-#: ../src/core/na-icontextual-factory.c:154
+#: ../src/core/na-icontext-factory.c:154
 msgid ""
 "Set to 'true' if the selection can have folders, to 'false' otherwise.\n"
 "This setting is tied in with the 'isfile' setting. The valid combinations "
@@ -674,11 +674,11 @@ msgstr ""
 "Dies trifft nur zu, wenn auf eine Auswahl abgezielt wird.\n"
 "Vorgabe ist »falsch«."
 
-#: ../src/core/na-icontextual-factory.c:181
+#: ../src/core/na-icontext-factory.c:181
 msgid "Whether the selection may be multiple"
 msgstr "Legt fest, ob Mehrfachauswahlen möglich sind"
 
-#: ../src/core/na-icontextual-factory.c:182
+#: ../src/core/na-icontext-factory.c:182
 msgid ""
 "If you need more than one files or folders to be selected, set this key to "
 "'true'. If you want just one file or folder, set it to 'false'.\n"
@@ -690,7 +690,7 @@ msgstr ""
 "Dies wirkt sich nur auf die Zielauswahl aus.\n"
 "Vorgabe ist »falsch«."
 
-#: ../src/core/na-icontextual-factory.c:204
+#: ../src/core/na-icontext-factory.c:204
 msgid ""
 "List of schemes to be matched against those of selected file(s)/folder(s)"
 msgstr ""
@@ -698,7 +698,7 @@ msgstr ""
 "zutreffen müssen"
 
 #. too long string for iso c: 510 (max=509)
-#: ../src/core/na-icontextual-factory.c:206
+#: ../src/core/na-icontext-factory.c:206
 #| msgid ""
 #| "Defines the list of valid schemes to be matched against the selected "
 #| "items. The scheme is the protocol used to access the files. The keyword to "
@@ -751,7 +751,7 @@ msgstr ""
 "oder wenn es auf das spezielle »x-nautilus-desktop«-Schema abzielt.\n"
 "Vorgabe ist »file«."
 
-#: ../src/core/na-icontextual-factory.c:233
+#: ../src/core/na-icontext-factory.c:233
 msgid ""
 "A valid GIO scheme where the selected file(s)/folder(s) should be located. "
 "You must set one option for each scheme you need"
@@ -760,7 +760,7 @@ msgstr ""
 "werden soll (Sie müssen jeweils eine Option für jedes Schema festlegen, dass "
 "Sie benötigen)"
 
-#: ../src/core/na-icontextual-factory.c:235
+#: ../src/core/na-icontext-factory.c:235
 #: ../src/core/na-object-action-factory.c:158
 #: ../src/core/na-object-item-factory.c:94
 #: ../src/core/na-object-item-factory.c:116
@@ -769,11 +769,11 @@ msgstr ""
 msgid "<STRING>"
 msgstr "<ZEICHENKETTE>"
 
-#: ../src/core/na-icontextual-factory.c:241
+#: ../src/core/na-icontext-factory.c:241
 msgid "List of folders"
 msgstr "Liste von Ordnern"
 
-#: ../src/core/na-icontextual-factory.c:242
+#: ../src/core/na-icontext-factory.c:242
 #| msgid ""
 #| "Defines the list of valid paths to be matched against the current folder.\n"
 #| " All folders 'under' the specified path are considered valid.\n"
@@ -790,7 +790,7 @@ msgstr ""
 "Alle Unterordner der angegebenen Adressen werden als gültig angesehen.\n"
 "Vorgabe ist »/«."
 
-#: ../src/core/na-icontextual-factory.c:256
+#: ../src/core/na-icontext-factory.c:256
 msgid ""
 "The path of a (parent) directory for which the item will be displayed. You "
 "must set one option for each folder you need"
@@ -798,7 +798,7 @@ msgstr ""
 "Die Adresse eines (Eltern-)Ordners, für den das Objekt angezeigt werden soll. "
 "Sie müssen jeweils eine Aktion für jeden benötigten Ordner festlegen."
 
-#: ../src/core/na-icontextual-factory.c:258
+#: ../src/core/na-icontext-factory.c:258
 #: ../src/core/na-object-profile-factory.c:86
 #: ../src/utils/nautilus-actions-new.c:132
 msgid "<PATH>"
diff --git a/po/es.po b/po/es.po
index abafa68..c29ed32 100644
--- a/po/es.po
+++ b/po/es.po
@@ -451,13 +451,15 @@ msgstr ""
 "Copyright %s 2005-2007 Frederic Ruaudel <grumz grumz net>\n"
 "Copyright %s 2009, 2010 Pierre Wieser <pwieser trychlos org>"
 
-#: ../src/core/na-icontextual-factory.c:47
+#: ../src/core/na-icontext-factory.c:47
+#, fuzzy
+#| msgid "The list of pattern to match the selected file(s)/folder(s)"
 msgid "List of patterns to be matched against the selected file(s)/folder(s)"
 msgstr ""
 "La lista de patrones con la que coincidir lo(s) archivo(s) y/o carpeta(s) "
 "seleccionada(s)"
 
-#: ../src/core/na-icontextual-factory.c:48
+#: ../src/core/na-icontext-factory.c:48
 #, fuzzy
 #| msgid ""
 #| "A list of strings with joker '*' or '?' to match the name of the selected "
@@ -475,7 +477,7 @@ msgstr ""
 "carpetas seleccionados. Cada elemento seleccionado debe coincidir al menos "
 "con uno de los patrones para que aparezca la acción"
 
-#: ../src/core/na-icontextual-factory.c:65
+#: ../src/core/na-icontext-factory.c:65
 #, fuzzy
 #| msgid ""
 #| "A pattern to match selected files against. May include wildcards (* or ?) "
@@ -487,18 +489,18 @@ msgstr ""
 "Un patrón para coincidir con los archivos seleccionados. Puede incluir "
 "comodines (? o *) (debe establecer una opción por cada patrón que necesite)"
 
-#: ../src/core/na-icontextual-factory.c:68
-#: ../src/core/na-icontextual-factory.c:119
+#: ../src/core/na-icontext-factory.c:68
+#: ../src/core/na-icontext-factory.c:119
 msgid "<EXPR>"
 msgstr "<EXPR>"
 
-#: ../src/core/na-icontextual-factory.c:74
+#: ../src/core/na-icontext-factory.c:74
 #, fuzzy
 #| msgid "Set it if the selection can have several items"
 msgid "Whether the specified basenames are case sensitive (default)"
 msgstr "Establézcalo si la selección puede contener varios elementos"
 
-#: ../src/core/na-icontextual-factory.c:75
+#: ../src/core/na-icontext-factory.c:75
 #, fuzzy
 #| msgid ""
 #| "If you need to match a filename in a case-sensitive manner, set this key "
@@ -516,7 +518,7 @@ msgstr ""
 "capitalización, ponga a «true» esta clave. Si quiere, por ejemplo que «*.jpg» "
 "coincida con «foto.JPG», póngala a «false»"
 
-#: ../src/core/na-icontextual-factory.c:99
+#: ../src/core/na-icontext-factory.c:99
 #, fuzzy
 #| msgid "The list of patterns to match the mimetypes of the selected file(s)"
 msgid ""
@@ -526,7 +528,7 @@ msgstr ""
 "La lista de patrones con la que coincidir los tipos MIME de los archivos "
 "seleccionados"
 
-#: ../src/core/na-icontextual-factory.c:100
+#: ../src/core/na-icontext-factory.c:100
 #, fuzzy
 #| msgid ""
 #| "A list of strings with joker '*' or '?' to match the mimetypes of the "
@@ -543,7 +545,7 @@ msgstr ""
 "de los archivos seleccionados. Cada elemento seleccionado debe coincidir al "
 "menos con uno de los patrones de tipos MIME para que aparezca la acción"
 
-#: ../src/core/na-icontextual-factory.c:116
+#: ../src/core/na-icontext-factory.c:116
 #, fuzzy
 #| msgid ""
 #| "A pattern to match selected files against. May include wildcards (* or ?) "
@@ -555,11 +557,17 @@ msgstr ""
 "Un patrón para coincidir con los archivos seleccionados. Puede incluir "
 "comodines (? o *) (debe establecer una opción por cada patrón que necesite)"
 
+<<<<<<< HEAD
 #: ../src/core/na-icontextual-factory.c:125
+=======
+#: ../src/core/na-icontext-factory.c:125
+#, fuzzy
+#| msgid "Whether the labels are the sames"
+>>>>>>> Refactor NAIContextual as NAIContext
 msgid "Whether the profile applies to files"
 msgstr "Indica si el perfil se aplica a archivos"
 
-#: ../src/core/na-icontextual-factory.c:126
+#: ../src/core/na-icontext-factory.c:126
 #, fuzzy
 #| msgid ""
 #| "The valid combinations are:\n"
@@ -591,11 +599,17 @@ msgstr ""
 "isfile=FALSE e isdir=FALSE: combinación inválida (su configuración nunca "
 "aparecerá)"
 
+<<<<<<< HEAD
 #: ../src/core/na-icontextual-factory.c:153
+=======
+#: ../src/core/na-icontext-factory.c:153
+#, fuzzy
+#| msgid "Whether the labels are the sames"
+>>>>>>> Refactor NAIContextual as NAIContext
 msgid "Whether the profile applies to folders"
 msgstr "Indica si el perfil se aplica a carpetas"
 
-#: ../src/core/na-icontextual-factory.c:154
+#: ../src/core/na-icontext-factory.c:154
 #, fuzzy
 #| msgid ""
 #| "The valid combinations are:\n"
@@ -627,11 +641,17 @@ msgstr ""
 "isfile=FALSE e isdir=FALSE: combinación inválida (su configuración nunca "
 "aparecerá)"
 
+<<<<<<< HEAD
 #: ../src/core/na-icontextual-factory.c:181
+=======
+#: ../src/core/na-icontext-factory.c:181
+#, fuzzy
+#| msgid "Whether the action is enabled"
+>>>>>>> Refactor NAIContextual as NAIContext
 msgid "Whether the selection may be multiple"
 msgstr "Indica si la selección puede ser múltiple"
 
-#: ../src/core/na-icontextual-factory.c:182
+#: ../src/core/na-icontext-factory.c:182
 #, fuzzy
 #| msgid ""
 #| "If you need one or more files or folders to be selected, set this key to "
@@ -645,7 +665,13 @@ msgstr ""
 "Si necesita que se selecciones uno o más archivos o carpetas, ponga a «true» "
 "esta clave. Si tan sólo quiere un archivo o carpeta, póngala a «false»"
 
+<<<<<<< HEAD
 #: ../src/core/na-icontextual-factory.c:204
+=======
+#: ../src/core/na-icontext-factory.c:204
+#, fuzzy
+#| msgid "The list of pattern to match the selected file(s)/folder(s)"
+>>>>>>> Refactor NAIContextual as NAIContext
 msgid ""
 "List of schemes to be matched against those of selected file(s)/folder(s)"
 msgstr ""
@@ -653,7 +679,7 @@ msgstr ""
 "seleccionada(s)"
 
 #. too long string for iso c: 510 (max=509)
-#: ../src/core/na-icontextual-factory.c:206
+#: ../src/core/na-icontext-factory.c:206
 #, fuzzy
 #| msgid ""
 #| "Defines the list of valid GnomeVFS schemes to be matched against the "
@@ -710,7 +736,15 @@ msgstr ""
 "\n"
 "Se pueden usar todos los esquemas GnomeVFS que use Nautilus aquí."
 
+<<<<<<< HEAD
 #: ../src/core/na-icontextual-factory.c:233
+=======
+#: ../src/core/na-icontext-factory.c:233
+#, fuzzy
+#| msgid ""
+#| "A valid GIO scheme where the selected files should be located. You must "
+#| "set one option for each scheme you need"
+>>>>>>> Refactor NAIContextual as NAIContext
 msgid ""
 "A valid GIO scheme where the selected file(s)/folder(s) should be located. "
 "You must set one option for each scheme you need"
@@ -718,7 +752,7 @@ msgstr ""
 "Un esquema GIO válido donde lo(s) archivo(s) y/o carpeta(s) seleccionada(s) "
 "deberían situarse. Debe establecer una opción para cada esquema que necesite."
 
-#: ../src/core/na-icontextual-factory.c:235
+#: ../src/core/na-icontext-factory.c:235
 #: ../src/core/na-object-action-factory.c:158
 #: ../src/core/na-object-item-factory.c:94
 #: ../src/core/na-object-item-factory.c:116
@@ -727,13 +761,13 @@ msgstr ""
 msgid "<STRING>"
 msgstr "<CADENA>"
 
-#: ../src/core/na-icontextual-factory.c:241
+#: ../src/core/na-icontext-factory.c:241
 #, fuzzy
 #| msgid "List of subitem ids"
 msgid "List of folders"
 msgstr "Lista de los ID de los subelementos"
 
-#: ../src/core/na-icontextual-factory.c:242
+#: ../src/core/na-icontext-factory.c:242
 #, fuzzy
 #| msgid ""
 #| "Defines the list of valid URIs to be matched against the current folder. "
@@ -748,7 +782,7 @@ msgstr ""
 "se usa al enfocar el fondo o la barra de herramientas. Todas las carpetas "
 "«bajo» el URI especificada se consideran inválidas."
 
-#: ../src/core/na-icontextual-factory.c:256
+#: ../src/core/na-icontext-factory.c:256
 #, fuzzy
 #| msgid ""
 #| "A valid GIO scheme where the selected files should be located. You must "
@@ -760,7 +794,7 @@ msgstr ""
 "Un esquema GIO válido donde los archivos seleccionados deberían situarse. "
 "Debe establecerla por cada esquema que necesite."
 
-#: ../src/core/na-icontextual-factory.c:258
+#: ../src/core/na-icontext-factory.c:258
 #: ../src/core/na-object-profile-factory.c:86
 #: ../src/utils/nautilus-actions-new.c:132
 msgid "<PATH>"
diff --git a/po/eu.po b/po/eu.po
index 8e68d66..2bb2e23 100644
--- a/po/eu.po
+++ b/po/eu.po
@@ -479,11 +479,11 @@ msgstr ""
 "Copyright-a %s 2005-2007 Frederic Ruaudel <grumz grumz net>\n"
 "Copyright-a %s 2009, 2010 Pierre Wieser <pwieser trychlos org>"
 
-#: ../src/core/na-icontextual-factory.c:47
+#: ../src/core/na-icontext-factory.c:47
 msgid "List of patterns to be matched against the selected file(s)/folder(s)"
 msgstr "Ereduen zerrenda hautatutako fitxategiak/karpetak bat etortzeko"
 
-#: ../src/core/na-icontextual-factory.c:48
+#: ../src/core/na-icontext-factory.c:48
 msgid ""
 "A list of strings with joker '*' or '?' to be matched against the name(s) of "
 "the selected file(s)/folder(s). Each selected items must match at least one "
@@ -498,7 +498,7 @@ msgstr ""
 "Hautapen bat dagoenean soilik aplikatzen da hau.\n"
 "Lehenetsi gisa '*'."
 
-#: ../src/core/na-icontextual-factory.c:65
+#: ../src/core/na-icontext-factory.c:65
 msgid ""
 "A pattern to be matched against basenames of selected file(s)/folder(s). May "
 "include wildcards (* or ?). You must set one option for each pattern you need"
@@ -507,18 +507,18 @@ msgstr ""
 "Komodinak (? edo *) eduki ditzake. Behar duzun eredu bakoitzeko aukera "
 "bat ezarri behar duzu."
 
-#: ../src/core/na-icontextual-factory.c:68
-#: ../src/core/na-icontextual-factory.c:119
+#: ../src/core/na-icontext-factory.c:68
+#: ../src/core/na-icontext-factory.c:119
 msgid "<EXPR>"
 msgstr "<ADIERA>"
 
-#: ../src/core/na-icontextual-factory.c:74
+#: ../src/core/na-icontext-factory.c:74
 msgid "Whether the specified basenames are case sensitive (default)"
 msgstr ""
 "Zehaztutako oinarrizko izenek maiuskulak eta minuskulak bereizten "
 "dituzten (lehenetsia) ala ez"
 
-#: ../src/core/na-icontextual-factory.c:75
+#: ../src/core/na-icontext-factory.c:75
 msgid ""
 "Must be set to 'true' if the filename patterns are case sensitive, to "
 "'false' otherwise. E.g., if you need to match a filename in a case-sensitive "
@@ -534,13 +534,13 @@ msgstr ""
 "Hautapen bat dagoenean soilik aplikatzen da hau.\n"
 "Lehenetsi gisa 'true'."
 
-#: ../src/core/na-icontextual-factory.c:99
+#: ../src/core/na-icontext-factory.c:99
 msgid ""
 "List of patterns to be matched against the mimetypes of the selected file(s)/"
 "folder(s)"
 msgstr "Ereduen zerrenda hautatutako fitxategi edo karpeten MIME motak bat etortzeko"
 
-#: ../src/core/na-icontextual-factory.c:100
+#: ../src/core/na-icontext-factory.c:100
 msgid ""
 "A list of strings with joker '*' to be matched against the mimetypes of the "
 "selected file(s)/folder(s). Each selected items must match at least one of "
@@ -554,7 +554,7 @@ msgstr ""
 "Hautapen bat dagoenean soilik aplikatzen da hau.\n"
 "Lehenetsi gisa '*'."
 
-#: ../src/core/na-icontextual-factory.c:116
+#: ../src/core/na-icontext-factory.c:116
 msgid ""
 "A pattern to be matched against mimetypes of selected file(s)/folder(s). May "
 "include wildcards (* or ?). You must set one option for each pattern you need"
@@ -562,11 +562,11 @@ msgstr ""
 "Eredua hautatutako fitxategi edo karpetak bat etortzeko. Komodinak (? edo *) eduki "
 "ditzake. Behar duzun eredu bakoitzeko aukera bat ezarri behar duzu."
 
-#: ../src/core/na-icontextual-factory.c:125
+#: ../src/core/na-icontext-factory.c:125
 msgid "Whether the profile applies to files"
 msgstr "Profilak fitxategiei aplikatuko zaizkien ala ez adierazten du"
 
-#: ../src/core/na-icontextual-factory.c:126
+#: ../src/core/na-icontext-factory.c:126
 msgid ""
 "Set to 'true' if the selection can have files, to 'false' otherwise.\n"
 "This setting is tied in with the 'isdir' setting. The valid combinations "
@@ -589,11 +589,11 @@ msgstr ""
 "Hautapen bat dagoenean soilik aplikatzen da hau.\n"
 "Lehenetsi gisa 'true'."
 
-#: ../src/core/na-icontextual-factory.c:153
+#: ../src/core/na-icontext-factory.c:153
 msgid "Whether the profile applies to folders"
 msgstr "Profilak karpetei aplikatuko zaien ala ez adierazten du"
 
-#: ../src/core/na-icontextual-factory.c:154
+#: ../src/core/na-icontext-factory.c:154
 msgid ""
 "Set to 'true' if the selection can have folders, to 'false' otherwise.\n"
 "This setting is tied in with the 'isfile' setting. The valid combinations "
@@ -616,11 +616,11 @@ msgstr ""
 "Hautapen bat dagoenean soilik aplikatzen da hau.\n"
 "Lehenetsi gisa 'false'."
 
-#: ../src/core/na-icontextual-factory.c:181
+#: ../src/core/na-icontext-factory.c:181
 msgid "Whether the selection may be multiple"
 msgstr "Hautapena anitzkoitza den ala ez adierazten du"
 
-#: ../src/core/na-icontextual-factory.c:182
+#: ../src/core/na-icontext-factory.c:182
 msgid ""
 "If you need more than one files or folders to be selected, set this key to "
 "'true'. If you want just one file or folder, set it to 'false'.\n"
@@ -633,12 +633,12 @@ msgstr ""
 "Hautapen bat dagoenean soilik aplikatzen da hau.\n"
 "Lehenetsi gisa 'false'."
 
-#: ../src/core/na-icontextual-factory.c:204
+#: ../src/core/na-icontext-factory.c:204
 msgid "List of schemes to be matched against those of selected file(s)/folder(s)"
 msgstr "Eskemen zerrenda hautatutako fitxategiak/karpetak bat etortzeko"
 
 #. too long string for iso c: 510 (max=509)
-#: ../src/core/na-icontextual-factory.c:206
+#: ../src/core/na-icontext-factory.c:206
 msgid ""
 "Defines the list of valid schemes to be matched against the selected items. "
 "The scheme is the protocol used to access the files. The keyword to use is "
@@ -676,7 +676,7 @@ msgstr ""
 "Hautapen bat dagoenean soilik aplikatzen da hau.\n"
 "Lehenetsi gisa 'file'."
 
-#: ../src/core/na-icontextual-factory.c:232
+#: ../src/core/na-icontext-factory.c:232
 msgid ""
 "A valid GIO scheme where the selected file(s)/folder(s) should be located. "
 "You must set one option for each scheme you need"
@@ -684,7 +684,7 @@ msgstr ""
 "Baliozko GIO eskema bat (hautatutako fitxategiak kokatuta egon beharko luketena). Behar "
 "duzun eskema bakoitzeko ezarri behar duzu"
 
-#: ../src/core/na-icontextual-factory.c:234
+#: ../src/core/na-icontext-factory.c:234
 #: ../src/core/na-object-action-factory.c:160
 #: ../src/core/na-object-item-factory.c:94
 #: ../src/core/na-object-item-factory.c:116
@@ -693,11 +693,11 @@ msgstr ""
 msgid "<STRING>"
 msgstr "<KATEA>"
 
-#: ../src/core/na-icontextual-factory.c:240
+#: ../src/core/na-icontext-factory.c:240
 msgid "List of folders"
 msgstr "Karpeten zerrenda"
 
-#: ../src/core/na-icontextual-factory.c:241
+#: ../src/core/na-icontext-factory.c:241
 msgid ""
 "Defines the list of valid paths to be matched against the current folder.\n"
 " All folders 'under' the specified path are considered valid.\n"
@@ -711,7 +711,7 @@ msgstr ""
 "bakarrik dituenean.\n"
 "Lehenetsia '/' da."
 
-#: ../src/core/na-icontextual-factory.c:256
+#: ../src/core/na-icontext-factory.c:256
 msgid ""
 "The path of a (parent) directory for which the item will be displayed. You "
 "must set one option for each folder you need"
@@ -719,7 +719,7 @@ msgstr ""
 "Direktorio (guraso) bate bide-izena, dagokion elementua bistaratzeko. "
 "Aukera bat ezarri behar duzu behar duzun karpeta bakoitzeko"
 
-#: ../src/core/na-icontextual-factory.c:258
+#: ../src/core/na-icontext-factory.c:258
 #: ../src/core/na-object-profile-factory.c:86
 #: ../src/utils/nautilus-actions-new.c:130
 msgid "<PATH>"
diff --git a/po/sl.po b/po/sl.po
index 0e4a289..74d0d41 100644
--- a/po/sl.po
+++ b/po/sl.po
@@ -325,11 +325,11 @@ msgstr ""
 "Avtorske pravice %s 2005-2007 Frederic Ruaudel <grumz grumz net>\n"
 "Avtorske pravice %s 2009, 2010 Pierre Wieser <pwieser trychlos org>"
 
-#: ../src/core/na-icontextual-factory.c:47
+#: ../src/core/na-icontext-factory.c:47
 msgid "List of patterns to be matched against the selected file(s)/folder(s)"
 msgstr "Seznam vzorcev za skladnje izbran-e/ih datotek(e) in map(e)"
 
-#: ../src/core/na-icontextual-factory.c:48
+#: ../src/core/na-icontext-factory.c:48
 msgid ""
 "A list of strings with joker '*' or '?' to be matched against the name(s) of the selected file(s)/folder(s). Each selected items must match at least one of the filename patterns for the action or the menu be candidate to display.\n"
 "This obviously only applies when there is a selection.\n"
@@ -339,20 +339,20 @@ msgstr ""
 "To je uporabljeno samo, ko obstaja izbor.\n"
 "Privzeto '*'."
 
-#: ../src/core/na-icontextual-factory.c:65
+#: ../src/core/na-icontext-factory.c:65
 msgid "A pattern to be matched against basenames of selected file(s)/folder(s). May include wildcards (* or ?). You must set one option for each pattern you need"
 msgstr "Vzorec za skladanje z izbranimi datotekami/mapami. Lahko vkljuÄ?uje nadomestna znaka (* ali ?). Nastaviti morate eno možnost za vsak vzorec, ki ga potrebujete"
 
-#: ../src/core/na-icontextual-factory.c:68
-#: ../src/core/na-icontextual-factory.c:119
+#: ../src/core/na-icontext-factory.c:68
+#: ../src/core/na-icontext-factory.c:119
 msgid "<EXPR>"
 msgstr "<IZRAZ>"
 
-#: ../src/core/na-icontextual-factory.c:74
+#: ../src/core/na-icontext-factory.c:74
 msgid "Whether the specified basenames are case sensitive (default)"
 msgstr "Ali so doloÄ?ena osnovna imena obÄ?utljiva na velikost Ä?rk (privzeto)"
 
-#: ../src/core/na-icontextual-factory.c:75
+#: ../src/core/na-icontext-factory.c:75
 msgid ""
 "Must be set to 'true' if the filename patterns are case sensitive, to 'false' otherwise. E.g., if you need to match a filename in a case-sensitive manner, set this key to 'true'. If you also want, for example '*.jpg' to match 'photo.JPG', then set 'false'.\n"
 "This obviously only applies when there is a selection.\n"
@@ -362,11 +362,11 @@ msgstr ""
 " To je uporabljeno samo, Ä?e obstaja izbor.\n"
 "Privzeto 'true'."
 
-#: ../src/core/na-icontextual-factory.c:99
+#: ../src/core/na-icontext-factory.c:99
 msgid "List of patterns to be matched against the mimetypes of the selected file(s)/folder(s)"
 msgstr "Seznam vzorcev za skladanje mime vrst izbran-e/ih datotek(e)/map(e)"
 
-#: ../src/core/na-icontextual-factory.c:100
+#: ../src/core/na-icontext-factory.c:100
 msgid ""
 "A list of strings with joker '*' to be matched against the mimetypes of the selected file(s)/folder(s). Each selected items must match at least one of the mimetype patterns for the action to appear.\n"
 "This obviously only applies when there is a selection.\n"
@@ -376,15 +376,15 @@ msgstr ""
 "To je uporabljeno samo, ko obstaja izbira.\n"
 "Privzeto '*'."
 
-#: ../src/core/na-icontextual-factory.c:116
+#: ../src/core/na-icontext-factory.c:116
 msgid "A pattern to be matched against mimetypes of selected file(s)/folder(s). May include wildcards (* or ?). You must set one option for each pattern you need"
 msgstr "Vzorec za skladanje z izbranimi datotekami/mapami. Lahko vkljuÄ?uje nadomestna znaka (* ali ?). Nastaviti morate eno možnost za vsak vzorec, ki ga potrebujete"
 
-#: ../src/core/na-icontextual-factory.c:125
+#: ../src/core/na-icontext-factory.c:125
 msgid "Whether the profile applies to files"
 msgstr "Ali je profil uveljavljen za datoteke"
 
-#: ../src/core/na-icontextual-factory.c:126
+#: ../src/core/na-icontext-factory.c:126
 msgid ""
 "Set to 'true' if the selection can have files, to 'false' otherwise.\n"
 "This setting is tied in with the 'isdir' setting. The valid combinations are: \n"
@@ -404,11 +404,11 @@ msgstr ""
 "To je uveljavljeno samo, Ä?e obstaja izbor.\n"
 "Privzeto 'true'."
 
-#: ../src/core/na-icontextual-factory.c:153
+#: ../src/core/na-icontext-factory.c:153
 msgid "Whether the profile applies to folders"
 msgstr "Ali je profil uveljavljen za mape"
 
-#: ../src/core/na-icontextual-factory.c:154
+#: ../src/core/na-icontext-factory.c:154
 msgid ""
 "Set to 'true' if the selection can have folders, to 'false' otherwise.\n"
 "This setting is tied in with the 'isfile' setting. The valid combinations are: \n"
@@ -428,11 +428,11 @@ msgstr ""
 "To je uporabljeno samo, ko obstaja izbor.\n"
 "Privzeto 'false'."
 
-#: ../src/core/na-icontextual-factory.c:181
+#: ../src/core/na-icontext-factory.c:181
 msgid "Whether the selection may be multiple"
 msgstr "Ali je lahko izbira veÄ?kratna"
 
-#: ../src/core/na-icontextual-factory.c:182
+#: ../src/core/na-icontext-factory.c:182
 msgid ""
 "If you need more than one files or folders to be selected, set this key to 'true'. If you want just one file or folder, set it to 'false'.\n"
 "This obviously only applies when there is a selection.\n"
@@ -442,12 +442,12 @@ msgstr ""
 "To je uporabljeno samo, ko obstaja izbor.\n"
 "Privzeto 'false'."
 
-#: ../src/core/na-icontextual-factory.c:204
+#: ../src/core/na-icontext-factory.c:204
 msgid "List of schemes to be matched against those of selected file(s)/folder(s)"
 msgstr "Seznam shem za skladnje izbran-e/ih datotek(e) in map(e)"
 
 #. too long string for iso c: 510 (max=509)
-#: ../src/core/na-icontextual-factory.c:206
+#: ../src/core/na-icontext-factory.c:206
 msgid ""
 "Defines the list of valid schemes to be matched against the selected items. The scheme is the protocol used to access the files. The keyword to use is the one used in the URI by the file manager.\n"
 "Examples of valid URI include:\n"
@@ -478,12 +478,13 @@ msgstr ""
 "To je uporabljeno samo ko obstaja izbor ali ob ciljanju posebne sheme 'x-nautilus-desktop'.\n"
 "Privzeto 'datoteka'"
 
-#: ../src/core/na-icontextual-factory.c:233
+#: ../src/core/na-icontext-factory.c:232
 msgid "A valid GIO scheme where the selected file(s)/folder(s) should be located. You must set one option for each scheme you need"
 msgstr "Veljavna shema GIO kjer naj bi se nahajale izbrane datoteke/mape. Nastaviti morate eno možnost za vsako shemo, ki jo potrebujete"
 
-#: ../src/core/na-icontextual-factory.c:235
-#: ../src/core/na-object-action-factory.c:158
+#: ../src/core/na-icontext-factory.c:234
+#: ../src/core/na-object-action-factory.c:160
+
 #: ../src/core/na-object-item-factory.c:94
 #: ../src/core/na-object-item-factory.c:116
 #: ../src/core/na-object-profile-factory.c:121
@@ -491,11 +492,12 @@ msgstr "Veljavna shema GIO kjer naj bi se nahajale izbrane datoteke/mape. Nastav
 msgid "<STRING>"
 msgstr "<NIZ>"
 
-#: ../src/core/na-icontextual-factory.c:241
+#: ../src/core/na-icontext-factory.c:240
 msgid "List of folders"
 msgstr "Seznam map"
 
-#: ../src/core/na-icontextual-factory.c:242
+#: ../src/core/na-icontext-factory.c:241
+
 msgid ""
 "Defines the list of valid paths to be matched against the current folder.\n"
 " All folders 'under' the specified path are considered valid.\n"
@@ -505,11 +507,11 @@ msgstr ""
 " Vse mape 'pod' doloÄ?eno potjo so obravnavane kot veljavne.\n"
 "Privzeta vrednost je '/'."
 
-#: ../src/core/na-icontextual-factory.c:256
+#: ../src/core/na-icontext-factory.c:256
 msgid "The path of a (parent) directory for which the item will be displayed. You must set one option for each folder you need"
 msgstr "Pod (nadrejene) mape za katero bo prikazan predmet. Nastaviti morate eno možnost za vsako mapo, ki jo potrebujete"
 
-#: ../src/core/na-icontextual-factory.c:258
+#: ../src/core/na-icontext-factory.c:258
 #: ../src/core/na-object-profile-factory.c:86
 #: ../src/utils/nautilus-actions-new.c:132
 msgid "<PATH>"
diff --git a/src/api/Makefile.am b/src/api/Makefile.am
index 3ab2927..2ba990f 100644
--- a/src/api/Makefile.am
+++ b/src/api/Makefile.am
@@ -44,7 +44,7 @@ api_include_HEADERS = \
 	na-data-types.h										\
 	na-gconf-monitor.h									\
 	na-gconf-utils.h									\
-	na-icontextual.h									\
+	na-icontext.h										\
 	na-iduplicable.h									\
 	na-ifactory-object.h								\
 	na-ifactory-object-data.h							\
diff --git a/src/api/na-object-api.h b/src/api/na-object-api.h
index 0c61b01..d6fb86a 100644
--- a/src/api/na-object-api.h
+++ b/src/api/na-object-api.h
@@ -44,7 +44,7 @@
 #include "na-ifactory-object.h"
 #include "na-ifactory-object-data.h"
 #include "na-iduplicable.h"
-#include "na-icontextual.h"
+#include "na-icontext.h"
 #include "na-object-action.h"
 #include "na-object-profile.h"
 #include "na-object-menu.h"
@@ -171,10 +171,10 @@ G_BEGIN_DECLS
 #define na_object_set_schemes( obj, schemes )			na_ifactory_object_set_from_void( NA_IFACTORY_OBJECT( obj ), NAFO_DATA_SCHEMES, ( const void * )( schemes ))
 #define na_object_set_folders( obj, folders )			na_ifactory_object_set_from_void( NA_IFACTORY_OBJECT( obj ), NAFO_DATA_FOLDERS, ( const void * )( folders ))
 
-/* NAIContextual
+/* NAIContext
  */
-#define na_object_set_scheme( obj, scheme, add )		na_icontextual_set_scheme( NA_ICONTEXTUAL( obj ), ( const gchar * )( scheme ), ( add ))
-#define na_object_replace_folder( obj, old, new )		na_icontextual_replace_folder( NA_ICONTEXTUAL( obj ), ( const gchar * )( old ), ( const gchar * )( new ))
+#define na_object_set_scheme( obj, scheme, add )		na_icontext_set_scheme( NA_ICONTEXT( obj ), ( const gchar * )( scheme ), ( add ))
+#define na_object_replace_folder( obj, old, new )		na_icontext_replace_folder( NA_ICONTEXT( obj ), ( const gchar * )( old ), ( const gchar * )( new ))
 
 G_END_DECLS
 
diff --git a/src/core/Makefile.am b/src/core/Makefile.am
index 0d606c9..94125b7 100644
--- a/src/core/Makefile.am
+++ b/src/core/Makefile.am
@@ -59,8 +59,8 @@ libna_core_la_SOURCES = \
 	na-gtk-utils.h										\
 	na-iabout.c											\
 	na-iabout.h											\
-	na-icontextual.c									\
-	na-icontextual-factory.c							\
+	na-icontext.c										\
+	na-icontext-factory.c								\
 	na-iduplicable.c									\
 	na-iexporter.c										\
 	na-ifactory-object.c								\
diff --git a/src/core/na-object-action.c b/src/core/na-object-action.c
index f30c946..4a3cb1b 100644
--- a/src/core/na-object-action.c
+++ b/src/core/na-object-action.c
@@ -687,7 +687,7 @@ na_object_action_attach_profile( NAObjectAction *action, NAObjectProfile *profil
  *
  * Returns: %TRUE if the @action may be candidate for this @target.
  *
- * Note that this public function will become NAIContextual::is_candidate
+ * Note that this public function will become NAIContext::is_candidate
  * when NAObjectAction will implement the interface.
  */
 gboolean
diff --git a/src/core/na-object-profile.c b/src/core/na-object-profile.c
index ff0b85c..a5037bf 100644
--- a/src/core/na-object-profile.c
+++ b/src/core/na-object-profile.c
@@ -83,7 +83,7 @@ static gboolean     ifactory_object_is_valid( const NAIFactoryObject *object );
 static void         ifactory_object_read_done( NAIFactoryObject *instance, const NAIFactoryProvider *reader, void *reader_data, GSList **messages );
 static guint        ifactory_object_write_done( NAIFactoryObject *instance, const NAIFactoryProvider *writer, void *writer_data, GSList **messages );
 
-static void         icontext_conditions_iface_init( NAIContextualInterface *iface );
+static void         icontext_conditions_iface_init( NAIContextInterface *iface );
 
 static gboolean     profile_is_valid( const NAObjectProfile *profile );
 static gboolean     is_valid_path_parameters( const NAObjectProfile *profile );
@@ -136,7 +136,7 @@ register_type( void )
 
 	type = g_type_register_static( NA_OBJECT_ID_TYPE, "NAObjectProfile", &info, 0 );
 
-	g_type_add_interface_static( type, NA_ICONTEXTUAL_TYPE, &icontext_conditions_iface_info );
+	g_type_add_interface_static( type, NA_ICONTEXT_TYPE, &icontext_conditions_iface_info );
 
 	g_type_add_interface_static( type, NA_IFACTORY_OBJECT_TYPE, &ifactory_object_iface_info );
 
@@ -337,7 +337,7 @@ ifactory_object_write_done( NAIFactoryObject *instance, const NAIFactoryProvider
 }
 
 static void
-icontext_conditions_iface_init( NAIContextualInterface *iface )
+icontext_conditions_iface_init( NAIContextInterface *iface )
 {
 	static const gchar *thisfn = "na_object_profile_icontext_conditions_iface_init";
 
@@ -355,7 +355,7 @@ profile_is_valid( const NAObjectProfile *profile )
 
 		is_valid = \
 				is_valid_path_parameters( profile ) &&
-				na_icontextual_is_valid( NA_ICONTEXTUAL( profile ));
+				na_icontext_is_valid( NA_ICONTEXT( profile ));
 	}
 
 	return( is_valid );
diff --git a/src/plugin-menu/nautilus-actions.c b/src/plugin-menu/nautilus-actions.c
index bfa10f7..0406ac9 100644
--- a/src/plugin-menu/nautilus-actions.c
+++ b/src/plugin-menu/nautilus-actions.c
@@ -562,7 +562,7 @@ build_nautilus_menus( NautilusActions *plugin, GList *tree, guint target, GList
 		}
 #endif
 
-		/*if( !na_icontextual_is_candidate( it->data, target, files )){
+		/*if( !na_icontext_is_candidate( it->data, target, files )){
 			continue;
 		}*/
 
@@ -588,7 +588,7 @@ build_nautilus_menus( NautilusActions *plugin, GList *tree, guint target, GList
 		g_return_val_if_fail( NA_IS_OBJECT_ACTION( it->data ), NULL );
 		action_label = na_object_get_label( it->data );
 
-		/* to be removed when NAObjectAction will implement NAIContextual interface
+		/* to be removed when NAObjectAction will implement NAIContext interface
 		 */
 		if( !na_object_action_is_candidate( it->data, target, files )){
 			g_debug( "%s: action %s is not candidate", thisfn, action_label );
@@ -627,7 +627,7 @@ get_candidate_profile( NautilusActions *plugin, NAObjectAction *action, guint ta
 	for( ip = profiles ; ip && !candidate ; ip = ip->next ){
 		NAObjectProfile *profile = NA_OBJECT_PROFILE( ip->data );
 
-		if( na_icontextual_is_candidate( NA_ICONTEXTUAL( profile ), target, files )){
+		if( na_icontext_is_candidate( NA_ICONTEXT( profile ), target, files )){
 			profile_label = na_object_get_label( profile );
 			g_debug( "%s: selecting %s (profile=%p '%s')", thisfn, action_label, ( void * ) profile, profile_label );
 			g_free( profile_label );
diff --git a/src/utils/nautilus-actions-run.c b/src/utils/nautilus-actions-run.c
index f7dc6d7..2dc9159 100644
--- a/src/utils/nautilus-actions-run.c
+++ b/src/utils/nautilus-actions-run.c
@@ -369,7 +369,7 @@ get_profile_for_targets( NAObjectAction *action, GList *targets )
 	profiles = na_object_get_items( action );
 	for( ip = profiles ; ip && !candidate ; ip = ip->next ){
 
-		if( na_icontextual_is_candidate( NA_ICONTEXTUAL( ip->data ), ITEM_TARGET_SELECTION, targets )){
+		if( na_icontext_is_candidate( NA_ICONTEXT( ip->data ), ITEM_TARGET_SELECTION, targets )){
 			candidate = NA_OBJECT_PROFILE( ip->data );
 		}
 	}



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/api/na-icontextual.h b/src/api/na-icontext.h
similarity index 57%
rename from src/api/na-icontextual.h
rename to src/api/na-icontext.h
index 3084ab0..cfcb8c9 100644
--- a/src/api/na-icontextual.h
+++ b/src/api/na-icontext.h
@@ -28,13 +28,13 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __NAUTILUS_ACTIONS_API_NA_ICONTEXTUAL_H__
-#define __NAUTILUS_ACTIONS_API_NA_ICONTEXTUAL_H__
+#ifndef __NAUTILUS_ACTIONS_API_NA_ICONTEXT_H__
+#define __NAUTILUS_ACTIONS_API_NA_ICONTEXT_H__
 
 /**
  * SECTION: na_icontextual
  * @short_description: #NAIContextual interface definition.
  * @include: nautilus-actions/na-icontextual.h
  *
  * This interface is implemented by all #NAObject-derived objects
  * whose the display in the Nautilus context menu is subject to some
@@ -49,22 +49,22 @@
 
 G_BEGIN_DECLS
 
-#define NA_ICONTEXTUAL_TYPE							( na_icontextual_get_type())
-#define NA_ICONTEXTUAL( instance )					( G_TYPE_CHECK_INSTANCE_CAST( instance, NA_ICONTEXTUAL_TYPE, NAIContextual ))
-#define NA_IS_ICONTEXTUAL( instance )				( G_TYPE_CHECK_INSTANCE_TYPE( instance, NA_ICONTEXTUAL_TYPE ))
-#define NA_ICONTEXTUAL_GET_INTERFACE( instance )	( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), NA_ICONTEXTUAL_TYPE, NAIContextualInterface ))
+#define NA_ICONTEXT_TYPE						( na_icontext_get_type())
+#define NA_ICONTEXT( instance )					( G_TYPE_CHECK_INSTANCE_CAST( instance, NA_ICONTEXT_TYPE, NAIContext ))
+#define NA_IS_ICONTEXT( instance )				( G_TYPE_CHECK_INSTANCE_TYPE( instance, NA_ICONTEXT_TYPE ))
+#define NA_ICONTEXT_GET_INTERFACE( instance )	( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), NA_ICONTEXT_TYPE, NAIContextInterface ))
 
-typedef struct NAIContextual                 NAIContextual;
+typedef struct NAIContext                 NAIContext;
 
-typedef struct NAIContextualInterfacePrivate NAIContextualInterfacePrivate;
+typedef struct NAIContextInterfacePrivate NAIContextInterfacePrivate;
 
 typedef struct {
-	GTypeInterface                 parent;
-	NAIContextualInterfacePrivate *private;
+	GTypeInterface              parent;
+	NAIContextInterfacePrivate *private;
 
 	/**
 	 * is_candidate:
-	 * @object: this #NAIContextual object.
+	 * @object: this #NAIContext object.
 	 * @target: the initial target which triggered this function's stack.
 	 *  This target is defined in na-object-item.h.
 	 * @selection: the current selection as a #GList of #NautilusFileInfo.
@@ -72,23 +72,23 @@ typedef struct {
 	 * Returns: %TRUE if the @object may be a potential candidate, %FALSE
 	 * else.
 	 *
 	 * The #NAIContextual implementor may take advantage of this
 	 * virtual function to check for its own specific data. Only if the
 	 * implementor does return %TRUE (or just doesn't implement this
 	 * virtual), the conditions themselves will be checked.
 	 */
-	gboolean ( *is_candidate )( NAIContextual *object, guint target, GList *selection );
+	gboolean ( *is_candidate )( NAIContext *object, guint target, GList *selection );
 }
-	NAIContextualInterface;
+	NAIContextInterface;
 
-GType    na_icontextual_get_type( void );
+GType    na_icontext_get_type( void );
 
-gboolean na_icontextual_is_candidate( const NAIContextual *object, guint target, GList *selection );
-gboolean na_icontextual_is_valid    ( const NAIContextual *object );
+gboolean na_icontext_is_candidate( const NAIContext *object, guint target, GList *selection );
+gboolean na_icontext_is_valid    ( const NAIContext *object );
 
-void     na_icontextual_set_scheme    ( NAIContextual *object, const gchar *scheme, gboolean selected );
-void     na_icontextual_replace_folder( NAIContextual *object, const gchar *old, const gchar *new );
+void     na_icontext_set_scheme    ( NAIContext *object, const gchar *scheme, gboolean selected );
+void     na_icontext_replace_folder( NAIContext *object, const gchar *old, const gchar *new );
 
 G_END_DECLS
 
-#endif /* __NAUTILUS_ACTIONS_API_NA_ICONTEXTUAL_H__ */
+#endif /* __NAUTILUS_ACTIONS_API_NA_ICONTEXT_H__ */
@@ -28,13 +28,13 @@
 
 /**
- * SECTION: na_icontextual
- * @short_description: #NAIContextual interface definition.
- * @include: nautilus-actions/na-icontextual.h
+ * SECTION: na_icontext
+ * @short_description: #NAIContext interface definition.
+ * @include: nautilus-actions/na-icontext.h
  *
  * This interface is implemented by all #NAObject-derived objects
@@ -72,23 +72,23 @@ typedef struct {
 	 * else.
 	 *
-	 * The #NAIContextual implementor may take advantage of this
+	 * The #NAIContext implementor may take advantage of this
 	 * virtual function to check for its own specific data. Only if the
 	 * implementor does return %TRUE (or just doesn't implement this
diff --git a/src/core/na-icontextual-factory.c b/src/core/na-icontext-factory.c
similarity index 100%
rename from src/core/na-icontextual-factory.c
rename to src/core/na-icontext-factory.c
diff --git a/src/core/na-icontextual.c b/src/core/na-icontext.c
similarity index 80%
rename from src/core/na-icontextual.c
rename to src/core/na-icontext.c
index e579cda..963774b 100644
--- a/src/core/na-icontextual.c
+++ b/src/core/na-icontext.c
@@ -44,7 +44,7 @@
 
 /* private interface data
  */
-struct NAIContextualInterfacePrivate {
+struct NAIContextInterfacePrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
@@ -52,30 +52,30 @@ static gboolean st_initialized = FALSE;
 static gboolean st_finalized   = FALSE;
 
 static GType    register_type( void );
-static void     interface_base_init( NAIContextualInterface *klass );
-static void     interface_base_finalize( NAIContextualInterface *klass );
+static void     interface_base_init( NAIContextInterface *klass );
+static void     interface_base_finalize( NAIContextInterface *klass );
 
-static gboolean v_is_candidate( NAIContextual *object, guint target, GList *selection );
+static gboolean v_is_candidate( NAIContext *object, guint target, GList *selection );
 
-static gboolean is_target_location_candidate( const NAIContextual *object, NASelectedInfo *current_folder );
-static gboolean is_target_toolbar_candidate( const NAIContextual *object, NASelectedInfo *current_folder );
-static gboolean is_current_folder_inside( const NAIContextual *object, NASelectedInfo *current_folder );
-static gboolean is_target_selection_candidate( const NAIContextual *object, GList *files );
-static gboolean is_valid_basenames( const NAIContextual *object );
-static gboolean is_valid_mimetypes( const NAIContextual *object );
-static gboolean is_valid_isfiledir( const NAIContextual *object );
-static gboolean is_valid_schemes( const NAIContextual *object );
-static gboolean is_valid_folders( const NAIContextual *object );
+static gboolean is_target_location_candidate( const NAIContext *object, NASelectedInfo *current_folder );
+static gboolean is_target_toolbar_candidate( const NAIContext *object, NASelectedInfo *current_folder );
+static gboolean is_current_folder_inside( const NAIContext *object, NASelectedInfo *current_folder );
+static gboolean is_target_selection_candidate( const NAIContext *object, GList *files );
+static gboolean is_valid_basenames( const NAIContext *object );
+static gboolean is_valid_mimetypes( const NAIContext *object );
+static gboolean is_valid_isfiledir( const NAIContext *object );
+static gboolean is_valid_schemes( const NAIContext *object );
+static gboolean is_valid_folders( const NAIContext *object );
 
 static gboolean validate_schemes( GSList *object_schemes, NASelectedInfo *iter );
 
 /**
- * na_icontextual_get_type:
+ * na_icontext_get_type:
  *
  * Returns: the #GType type of this interface.
  */
 GType
-na_icontextual_get_type( void )
+na_icontext_get_type( void )
 {
 	static GType type = 0;
 
@@ -87,18 +87,18 @@ na_icontextual_get_type( void )
 }
 
 /*
- * na_icontextual_register_type:
+ * na_icontext_register_type:
  *
  * Registers this interface.
  */
 static GType
 register_type( void )
 {
-	static const gchar *thisfn = "na_icontextual_register_type";
+	static const gchar *thisfn = "na_icontext_register_type";
 	GType type;
 
 	static const GTypeInfo info = {
-		sizeof( NAIContextualInterface ),
+		sizeof( NAIContextInterface ),
 		( GBaseInitFunc ) interface_base_init,
 		( GBaseFinalizeFunc ) interface_base_finalize,
 		NULL,
@@ -111,7 +111,7 @@ register_type( void )
 
 	g_debug( "%s", thisfn );
 
-	type = g_type_register_static( G_TYPE_INTERFACE, "NAIContextual", &info, 0 );
+	type = g_type_register_static( G_TYPE_INTERFACE, "NAIContext", &info, 0 );
 
 	g_type_interface_add_prerequisite( type, G_TYPE_OBJECT );
 
@@ -119,24 +119,24 @@ register_type( void )
 }
 
 static void
-interface_base_init( NAIContextualInterface *klass )
+interface_base_init( NAIContextInterface *klass )
 {
-	static const gchar *thisfn = "na_icontextual_interface_base_init";
+	static const gchar *thisfn = "na_icontext_interface_base_init";
 
 	if( !st_initialized ){
 
 		g_debug( "%s: klass%p (%s)", thisfn, ( void * ) klass, G_OBJECT_CLASS_NAME( klass ));
 
-		klass->private = g_new0( NAIContextualInterfacePrivate, 1 );
+		klass->private = g_new0( NAIContextInterfacePrivate, 1 );
 
 		st_initialized = TRUE;
 	}
 }
 
 static void
-interface_base_finalize( NAIContextualInterface *klass )
+interface_base_finalize( NAIContextInterface *klass )
 {
-	static const gchar *thisfn = "na_icontextual_interface_base_finalize";
+	static const gchar *thisfn = "na_icontext_interface_base_finalize";
 
 	if( st_initialized && !st_finalized ){
 
@@ -149,8 +149,8 @@ interface_base_finalize( NAIContextualInterface *klass )
 }
 
 /**
  * na_icontextual_is_candidate:
  * @object: a #NAIContextual to be checked.
  * @target: the current target.
  * @files: the currently selected items, as a #GList of #NASelectedInfo items.
  *
@@ -163,13 +163,13 @@ interface_base_finalize( NAIContextualInterface *klass )
  * else.
  */
 gboolean
-na_icontextual_is_candidate( const NAIContextual *object, guint target, GList *files )
+na_icontext_is_candidate( const NAIContext *object, guint target, GList *files )
 {
 	gboolean is_candidate;
 
-	g_return_val_if_fail( NA_IS_ICONTEXTUAL( object ), FALSE );
+	g_return_val_if_fail( NA_IS_ICONTEXT( object ), FALSE );
 
-	is_candidate = v_is_candidate( NA_ICONTEXTUAL( object ), target, files );
+	is_candidate = v_is_candidate( NA_ICONTEXT( object ), target, files );
 
 	switch( target ){
 		case ITEM_TARGET_LOCATION:
@@ -189,23 +189,23 @@ na_icontextual_is_candidate( const NAIContextual *object, guint target, GList *f
 }
 
 /**
- * na_icontextual_is_valid:
+ * na_icontext_is_valid:
  * @profile: the #NAObjectProfile to be checked.
  *
  * Returns: %TRUE if this profile is valid, %FALSE else.
  *
  * This function is part of NAIDuplicable::check_status() and is called
  * by NAIDuplicable objects which also implement NAIContextual
  * interface. It so doesn't make sense of asking the object for its
  * validity status as it has already been checked before calling the
  * function.
  */
 gboolean
-na_icontextual_is_valid( const NAIContextual *object )
+na_icontext_is_valid( const NAIContext *object )
 {
 	gboolean is_valid;
 
-	g_return_val_if_fail( NA_IS_ICONTEXTUAL( object ), FALSE );
+	g_return_val_if_fail( NA_IS_ICONTEXT( object ), FALSE );
 
 	is_valid =
 		is_valid_basenames( object ) &&
@@ -218,21 +218,21 @@ na_icontextual_is_valid( const NAIContextual *object )
 }
 
 /**
- * na_icontextual_set_scheme:
- * @profile: the #NAIContextual to be updated.
+ * na_icontext_set_scheme:
+ * @profile: the #NAIContext to be updated.
  * @scheme: name of the scheme.
  * @selected: whether this scheme is candidate to this profile.
  *
  * Sets the status of a scheme relative to this profile.
  */
 void
-na_icontextual_set_scheme( NAIContextual *profile, const gchar *scheme, gboolean selected )
+na_icontext_set_scheme( NAIContext *profile, const gchar *scheme, gboolean selected )
 {
-	/*static const gchar *thisfn = "na_icontextual_set_scheme";*/
+	/*static const gchar *thisfn = "na_icontext_set_scheme";*/
 	gboolean exist;
 	GSList *schemes;
 
-	g_return_if_fail( NA_IS_ICONTEXTUAL( profile ));
+	g_return_if_fail( NA_IS_ICONTEXT( profile ));
 
 	schemes = na_object_get_schemes( profile );
 	exist = na_core_utils_slist_find( schemes, scheme );
@@ -249,19 +249,19 @@ na_icontextual_set_scheme( NAIContextual *profile, const gchar *scheme, gboolean
 }
 
 /**
- * na_icontextual_replace_folder:
- * @profile: the #NAIContextual to be updated.
+ * na_icontext_replace_folder:
+ * @profile: the #NAIContext to be updated.
  * @old: the old uri.
  * @new: the new uri.
  *
  * Replaces the @old URI by the @new one.
  */
 void
-na_icontextual_replace_folder( NAIContextual *profile, const gchar *old, const gchar *new )
+na_icontext_replace_folder( NAIContext *profile, const gchar *old, const gchar *new )
 {
 	GSList *folders;
 
-	g_return_if_fail( NA_IS_ICONTEXTUAL( profile ));
+	g_return_if_fail( NA_IS_ICONTEXT( profile ));
 
 	folders = na_object_get_folders( profile );
 	folders = na_core_utils_slist_remove_utf8( folders, old );
@@ -271,21 +271,21 @@ na_icontextual_replace_folder( NAIContextual *profile, const gchar *old, const g
 }
 
 static gboolean
-v_is_candidate( NAIContextual *object, guint target, GList *selection )
+v_is_candidate( NAIContext *object, guint target, GList *selection )
 {
 	gboolean is_candidate;
 
 	is_candidate = TRUE;
 
-	if( NA_ICONTEXTUAL_GET_INTERFACE( object )->is_candidate ){
-		is_candidate = NA_ICONTEXTUAL_GET_INTERFACE( object )->is_candidate( object, target, selection );
+	if( NA_ICONTEXT_GET_INTERFACE( object )->is_candidate ){
+		is_candidate = NA_ICONTEXT_GET_INTERFACE( object )->is_candidate( object, target, selection );
 	}
 
 	return( is_candidate );
 }
 
 static gboolean
-is_target_location_candidate( const NAIContextual *object, NASelectedInfo *current_folder )
+is_target_location_candidate( const NAIContext *object, NASelectedInfo *current_folder )
 {
 	gboolean is_candidate;
 
@@ -295,7 +295,7 @@ is_target_location_candidate( const NAIContextual *object, NASelectedInfo *curre
 }
 
 static gboolean
-is_target_toolbar_candidate( const NAIContextual *object, NASelectedInfo *current_folder )
+is_target_toolbar_candidate( const NAIContext *object, NASelectedInfo *current_folder )
 {
 	gboolean is_candidate;
 
@@ -305,7 +305,7 @@ is_target_toolbar_candidate( const NAIContextual *object, NASelectedInfo *curren
 }
 
 static gboolean
-is_current_folder_inside( const NAIContextual *object, NASelectedInfo *current_folder )
+is_current_folder_inside( const NAIContext *object, NASelectedInfo *current_folder )
 {
 	gboolean is_inside;
 	GSList *folders, *ifold;
@@ -331,7 +331,7 @@ is_current_folder_inside( const NAIContextual *object, NASelectedInfo *current_f
 }
 
 static gboolean
-is_target_selection_candidate( const NAIContextual *object, GList *files )
+is_target_selection_candidate( const NAIContext *object, GList *files )
 {
 	gboolean retv = FALSE;
 	GSList *basenames, *mimetypes, *schemes;
@@ -528,7 +528,7 @@ is_target_selection_candidate( const NAIContextual *object, GList *files )
 }
 
 static gboolean
-is_valid_basenames( const NAIContextual *object )
+is_valid_basenames( const NAIContext *object )
 {
 	gboolean valid;
 	GSList *basenames;
@@ -545,7 +545,7 @@ is_valid_basenames( const NAIContextual *object )
 }
 
 static gboolean
-is_valid_mimetypes( const NAIContextual *object )
+is_valid_mimetypes( const NAIContext *object )
 {
 	gboolean valid;
 	GSList *mimetypes;
@@ -562,7 +562,7 @@ is_valid_mimetypes( const NAIContextual *object )
 }
 
 static gboolean
-is_valid_isfiledir( const NAIContextual *object )
+is_valid_isfiledir( const NAIContext *object )
 {
 	gboolean valid;
 	gboolean isfile, isdir;
@@ -580,7 +580,7 @@ is_valid_isfiledir( const NAIContextual *object )
 }
 
 static gboolean
-is_valid_schemes( const NAIContextual *object )
+is_valid_schemes( const NAIContext *object )
 {
 	gboolean valid;
 	GSList *schemes;
@@ -597,7 +597,7 @@ is_valid_schemes( const NAIContextual *object )
 }
 
 static gboolean
-is_valid_folders( const NAIContextual *object )
+is_valid_folders( const NAIContext *object )
 {
 	gboolean valid;
 	GSList *folders;
@@ -149,8 +149,8 @@ interface_base_finalize( NAIContextualInterface *klass )
 
 /**
- * na_icontextual_is_candidate:
- * @object: a #NAIContextual to be checked.
+ * na_icontext_is_candidate:
+ * @object: a #NAIContext to be checked.
  * @target: the current target.
  * @files: the currently selected items, as a #GList of #NASelectedInfo items.
@@ -189,23 +189,23 @@ na_icontextual_is_candidate( const NAIContextual *object, guint target, GList *f
  *
  * This function is part of NAIDuplicable::check_status() and is called
- * by NAIDuplicable objects which also implement NAIContextual
+ * by NAIDuplicable objects which also implement NAIContext
  * interface. It so doesn't make sense of asking the object for its
  * validity status as it has already been checked before calling the